package cli::crosstable;

use 5.006;
use strict;
use warnings;

=head1 NAME

cli::crosstable - A simple script to produce crosstable (2-way contingency table) with various switch options.

The command details are shown by as follows: 

  crosstable --help 

=head1 VERSION

Version 1.04

=cut

our $VERSION = '1.04';


=head1 AUTHOR

"Toshiyuki Shimono", C<< <bin4tsv at gmail.com> >>


=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.


=cut

1; # End of cli::crosstable
